About
=====
TradeDangerous is set of powerful trading tools for Elite Dangerous,
organized around one of the most powerful trade run optimizers available.

The TRO is a heavy hitter that can calculate complex routes with multiple
stops while taking into account the profits you make along the route
The price data in TradeDangerous is either manually entered or crowd sourced from a website
such as [Tromador's Trading Dangerously](http://elite.ripz.org "Tromador's Trading Dangerously"), often using a plugin such as the included eddblink.


